# Table of Contents

- [outbound-processors](<./outbound-processors.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Outbound Processors](<./Outbound-Processors.md>)
  - [Overview](<./Outbound-Processors/Overview.md>)
  - [Setting the Scope](<./Outbound-Processors/Setting-the-Scope.md>)
  - [Setting the Fields](<./Outbound-Processors/Setting-the-Fields.md>)
  - [Setting Filters](<./Outbound-Processors/Setting-Filters.md>)
  - [Outbound Fact Sheet](<./Outbound-Processors/Outbound-Fact-Sheet.md>)
  - [Exporting Relations](<./Outbound-Processors/Exporting-Relations.md>)
  - [Exporting All Relations and Fields within Relations](<./Outbound-Processors/Exporting-All-Relations-and-Fields-within-Relations.md>)
  - [Exporting Constraining Relations](<./Outbound-Processors/Exporting-Constraining-Relations.md>)
  - [Exporting Tags and Subscriptions](<./Outbound-Processors/Exporting-Tags-and-Subscriptions.md>)
  - [Write LDIF using Modes, Map and ForEach](<./Outbound-Processors/Write-LDIF-using-Modes-Map-and-ForEach.md>)
  - [Use Relations to Create Separate Data Object](<./Outbound-Processors/Use-Relations-to-Create-Separate-Data-Object.md>)
  - [Export Metrics](<./Outbound-Processors/Export-Metrics.md>)
  - [Filtering on items that have changed recently](<./Outbound-Processors/Filtering-on-items-that-have-changed-recently.md>)
  - [Translate list entries](<./Outbound-Processors/Translate-list-entries.md>)
  - [How to export Fact Sheets that are archived](<./Outbound-Processors/How-to-export-Fact-Sheets-that-are-archived.md>)
  - [How to export large amounts of data](<./Outbound-Processors/How-to-export-large-amounts-of-data.md>)
  - [Was this page helpful?](<./Outbound-Processors/Was-this-page-helpful.md>)
